@@ -39,11 +39,11 @@
  * 3.1.2b1 would be 0x03010201.  Snapshot from Jan 2, 2003 would be
  * 0xFF030102.
  * See TSK_VERSION_STR for string form. */
-#define TSK_VERSION_NUM 0x040200ff
+#define TSK_VERSION_NUM 0x041100ff
 
 /** Version of code in string form. See TSK_VERSION_NUM for
  * integer form. */
-#define TSK_VERSION_STR "4.2.0"
+#define TSK_VERSION_STR "4.11.0"
 
 
 /* include the TSK-specific header file that we created in autoconf
@@ -56,6 +56,10 @@
 // get some other TSK / OS settings
 #include "tsk_os.h"
 
+#ifdef TSK_WIN32
+#define strncasecmp _strnicmp
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -108,10 +112,10 @@ extern "C" {
     } tsk_lock_t;
 
     // non-windows
-#else 
+#else
 /* Note that there is an assumption that TSK_MULTITHREADED_LIB was
- * set only if we have ptheads. If we add a check for HAVE_PTHREAD 
- * here, it causes problems when you try to include the library in 
+ * set only if we have pthreads. If we add a check for HAVE_PTHREAD
+ * here, it causes problems when you try to include the library in
  * a tool because they do not have tsk_config.h included.
  */
 #include <pthread.h>
@@ -177,6 +181,8 @@ extern "C" {
     extern void tsk_fprintf(FILE * fd, const char *msg, ...);
     extern void tsk_printf(const char *msg, ...);
 
+    // print path removing special characters
+    extern int tsk_print_sanitized(FILE * fd, const char *str);
 
 
 /** \name printf macros if system does not define them */
@@ -245,32 +251,26 @@ extern "C" {
     typedef uint64_t TSK_INUM_T;        ///< Data type used to internally store metadata / inode addresses
 #define PRIuINUM	PRIu64
 #define PRIxINUM	PRIx64
-#define PRIdINUM	PRId64
 
     typedef uint32_t TSK_UID_T; ///< Data type used to internally store User IDs
 #define PRIuUID	    PRIu32
 #define PRIxUID	    PRIx32
-#define PRIdUID	    PRId32
 
     typedef uint32_t TSK_GID_T; ///< Data type used to internally store Group IDs
 #define PRIuGID	    PRIu32
 #define PRIxGID	    PRIx32
-#define PRIdGID	    PRId32
 
     typedef uint64_t TSK_DADDR_T;       ///< Data type used to internally store sector and block addresses
 #define PRIuDADDR   PRIu64
 #define PRIxDADDR   PRIx64
-#define PRIdDADDR   PRId64
 
     typedef int64_t TSK_OFF_T;  ///< Data type used to internally store volume, file, etc. sizes and offsets
-#define PRIuOFF		PRIu64
 #define PRIxOFF		PRIx64
 #define PRIdOFF		PRId64
 
     typedef uint32_t TSK_PNUM_T;        ///< Data type used to internally store partition addresses
 #define PRIuPNUM	PRIu32
 #define PRIxPNUM	PRIx32
-#define PRIdPNUM	PRId32
 //@}
 
 
@@ -286,7 +286,7 @@ extern "C" {
     typedef enum {
         TSK_WALK_CONT = 0x0,    ///< Walk function should continue to next object
         TSK_WALK_STOP = 0x1,    ///< Walk function should stop processing units and return OK
-        TSK_WALK_ERROR = 0x2,   ///< Walk function should stop processing units and return error
+        TSK_WALK_ERROR = 0x2   ///< Walk function should stop processing units and return error
     } TSK_WALK_RET_ENUM;
 
 
@@ -301,6 +301,7 @@ extern "C" {
 #define TSK_ERR_FS	0x08000000
 #define TSK_ERR_HDB	0x10000000
 #define TSK_ERR_AUTO 0x20000000
+#define TSK_ERR_POOL 0x40000000
 #define TSK_ERR_MASK	0x00ffffff
 
 #define TSK_ERR_AUX_MALLOC	(TSK_ERR_AUX | 0)
@@ -331,7 +332,14 @@ extern "C" {
 #define TSK_ERR_VS_BUF		(TSK_ERR_VS | 5)
 #define TSK_ERR_VS_BLK_NUM	(TSK_ERR_VS | 6)
 #define TSK_ERR_VS_ARG	    (TSK_ERR_VS | 7)
-#define TSK_ERR_VS_MAX		8
+#define TSK_ERR_VS_ENCRYPTED    (TSK_ERR_VS | 8)
+#define TSK_ERR_VS_MAX		9
+
+#define TSK_ERR_POOL_UNKTYPE    (TSK_ERR_POOL | 0)
+#define TSK_ERR_POOL_UNSUPTYPE  (TSK_ERR_IMG | 1)
+#define TSK_ERR_POOL_ARG        (TSK_ERR_POOL | 2)
+#define TSK_ERR_POOL_GENPOOL    (TSK_ERR_POOL | 3)
+#define TSK_ERR_POOL_MAX        4
 
 #define TSK_ERR_FS_UNKTYPE	(TSK_ERR_FS | 0)
 #define TSK_ERR_FS_UNSUPTYPE	(TSK_ERR_FS | 1)
@@ -351,8 +359,9 @@ extern "C" {
 #define TSK_ERR_FS_GENFS	(TSK_ERR_FS | 15)
 #define TSK_ERR_FS_CORRUPT	(TSK_ERR_FS | 16)
 #define TSK_ERR_FS_ATTR_NOTFOUND (TSK_ERR_FS | 17)
-#define TSK_ERR_FS_MAX		18
-
+#define TSK_ERR_FS_ENCRYPTED    (TSK_ERR_FS | 18)
+#define TSK_ERR_FS_POSSIBLY_ENCRYPTED    (TSK_ERR_FS | 19)
+#define TSK_ERR_FS_MAX		20
 
 #define TSK_ERR_HDB_UNKTYPE     (TSK_ERR_HDB | 0)
 #define TSK_ERR_HDB_UNSUPTYPE   (TSK_ERR_HDB | 1)
@@ -519,14 +528,14 @@ class TskStack {
     /**
     * Push a value to the top of TSK_STACK. See tsk_stack_push() for details.
     * @param a_val Value to push on
-    * @returns 1 on error 
+    * @returns 1 on error
     */
     uint8_t push(uint64_t a_val) {
         return tsk_stack_push(m_stack, a_val);
     };
     /**
     * Search a TSK_STACK for a given value. See tsk_stack_find() for details.
-    * @param a_val Value to search for 
+    * @param a_val Value to search for
     * @returns 1 if found and 0 if not
     */
     uint8_t find(uint64_t a_val) {
@@ -552,7 +561,7 @@ class TskStack {
 class TskError {
   public:
     /**
-    * Return the string with the current error message.  The string does not end with a 
+    * Return the string with the current error message.  The string does not end with a
     * newline. See tsk_error_get() for details.
     *
     * @returns String with error message or NULL if there is no error
